==> verovio-3.15.0.tar.gz: verovio-3.15.0/include/vrv/featureextractor.h <==
/////////////////////////////////////////////////////////////////////////////
// Name:        featureextractor.h
// Author:      Laurent Pugin
// Created:     2021
// Copyright (c) Authors and others. All rights reserved.
/////////////////////////////////////////////////////////////////////////////

#ifndef __VRV_FEATURE_EXTRACTOR_H__
#define __VRV_FEATURE_EXTRACTOR_H__

//----------------------------------------------------------------------------

#include "functorparams.h"
#include "options.h"

//----------------------------------------------------------------------------

#include "jsonxx.h"

namespace vrv {

class FeatureExtractor {

public:
    /**
     * @name Constructors, destructors, reset methods
     * Reset method resets all attribute classes
     */
    ///@{
    FeatureExtractor(const std::string &options);
    virtual ~FeatureExtractor();
    ///@}

    /*
     * Clear the content of the feature extractor.
     */
    virtual void Reset();

    /**
     * Extract a feature for the object
     */
    void Extract(Object *object, GenerateFeaturesParams *params);

    /**
     * Write the current content of the extractor to a JSON string
     */
    void ToJson(std::string &output);

private:
    //
public:
    /**
     * A list of previous notes for interval calculation.
     * Usually one note, but sometimes more than one with tied notes.
     */
    std::list<Note *> m_previousNotes;

    jsonxx::Array m_pitchesChromatic;
    jsonxx::Array m_pitchesDiatonic;
    jsonxx::Array m_pitchesIds;

    jsonxx::Array m_intervalsChromatic;
    jsonxx::Array m_intervalsDiatonic;
    jsonxx::Array m_intervalGrossContour;
    jsonxx::Array m_intervalRefinedContour;
    jsonxx::Array m_intervalsIds;

private:
};

} // namespace vrv

#endif

==> verovio-4.0.1.tar.gz: verovio-4.0.1/include/vrv/featureextractor.h <==
/////////////////////////////////////////////////////////////////////////////
// Name:        featureextractor.h
// Author:      Laurent Pugin
// Created:     2021
// Copyright (c) Authors and others. All rights reserved.
/////////////////////////////////////////////////////////////////////////////

#ifndef __VRV_FEATURE_EXTRACTOR_H__
#define __VRV_FEATURE_EXTRACTOR_H__

//----------------------------------------------------------------------------

#include "options.h"

//----------------------------------------------------------------------------

#include "jsonxx.h"

namespace vrv {

class FeatureExtractor {

public:
    /**
     * @name Constructors, destructors, reset methods
     * Reset method resets all attribute classes
     */
    ///@{
    FeatureExtractor(const std::string &options);
    virtual ~FeatureExtractor();
    ///@}

    /*
     * Clear the content of the feature extractor.
     */
    virtual void Reset();

    /**
     * Extract a feature for the object
     */
    void Extract(const Object *object);

    /**
     * Write the current content of the extractor to a JSON string
     */
    void ToJson(std::string &output);

private:
    //
public:
    /**
     * A list of previous notes for interval calculation.
     * Usually one note, but sometimes more than one with tied notes.
     */
    std::list<const Note *> m_previousNotes;

    jsonxx::Array m_pitchesChromatic;
    jsonxx::Array m_pitchesDiatonic;
    jsonxx::Array m_pitchesIds;

    jsonxx::Array m_intervalsChromatic;
    jsonxx::Array m_intervalsDiatonic;
    jsonxx::Array m_intervalGrossContour;
    jsonxx::Array m_intervalRefinedContour;
    jsonxx::Array m_intervalsIds;

private:
};

} // namespace vrv

#endif
